"use strict";
exports.__esModule = true;
var react_1 = require("react");
var react_native_1 = require("react-native");
var TEXT_WITH_BRACKETS = new RegExp(/(\[\[.+?\]\])/);
var TEXT_AMONG_BRACKETS = new RegExp(/\[\[(.*)\]\]/);
var KEY_VALUE = new RegExp(/^\w[,\w]+=\w+/);
var HighlightedText = function (props) {
    var children = props.children, _a = props.highlightedTextStyles, highlightedTextStyles = _a === void 0 ? [] : _a;
    var textFormated = react_1.useMemo(function () {
        var currentStyleIndex = 0;
        var textArray = children.split(TEXT_WITH_BRACKETS);
        var createStyledElement = function (_a) {
            var text = _a.text, style = _a.style, jsxElement = _a.jsxElement;
            return (<>
        {jsxElement}
        <react_native_1.Text {...props} style={[props.style, style]}>
          {text}
        </react_native_1.Text>
      </>);
        };
        var finalTextElement = textArray.reduce(function (jsxElement, text) {
            if (TEXT_WITH_BRACKETS.test(text)) {
                var pureText = text.replace(TEXT_AMONG_BRACKETS, '$1');
                if (!highlightedTextStyles) {
                    return createStyledElement({ text: pureText, jsxElement: jsxElement });
                }
                if (Array.isArray(highlightedTextStyles)) {
                    var style = highlightedTextStyles[currentStyleIndex];
                    currentStyleIndex += 1;
                    return createStyledElement({ text: pureText, jsxElement: jsxElement, style: style });
                }
                var keyAndText = KEY_VALUE.test(pureText)
                    ? pureText.split('=')
                    : undefined;
                var keys = keyAndText && keyAndText[0].split(',');
                if (keyAndText && keys) {
                    var styles = keys.map(function (key) { return highlightedTextStyles[key]; });
                    var finalText = keyAndText[1];
                    return createStyledElement({
                        text: finalText,
                        jsxElement: jsxElement,
                        style: styles
                    });
                }
                return createStyledElement({ text: pureText, jsxElement: jsxElement });
            }
            return (<>
          {jsxElement}
          {text}
        </>);
        }, <></>);
        return finalTextElement;
    }, [children, highlightedTextStyles, props]);
    return <react_native_1.Text {...props}>{textFormated}</react_native_1.Text>;
};
exports["default"] = HighlightedText;
